OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Download" : "Изтегляне",
    "Delete" : "Изтриване",
    "Rename" : "Преименуване",
    "Share with users or groups" : "Споделяне с потребители или групи",
    "can edit" : "може да редактира",
    "Close" : "Затвори",
    "Enabled" : "Включено",
    "Disabled" : "Изключено",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C.",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C.",
    "Address book name" : "Име на адресна книга ",
    "Only these special characters are allowed: -_.!?#|()" : "Само тези специални знаци са разрешени: -_.!?#|()",
    "Address book could not be created." : "Адресната книга не може да бъде създадена.",
    "The selected image is too big (max 1MB)" : "Избраното изображение е много голямо (до 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Тази визитка е повредена и е била поправена. Моля, проверете данните и инициирайте запазване, за да останат промените за постоянно.",
    "No contacts in here" : "Тук няма контакти",
    "Name" : "Име",
    "Organization" : "Организация",
    "Title" : "Заглавие",
    "Add field …" : "Добавяне на поле ...",
    "Save changes" : "Запис на промените",
    "Address book" : "Адресна книга",
    "Loading contacts …" : "Зареждане на контактите ...",
    "Importing..." : "Внасяне ...",
    "No search result for {query}" : "Няма намерени резултати за {query}",
    "All contacts" : "Всички контакти",
    "Post office box" : "Пощенска кутия",
    "Postal code" : "Пощенски код",
    "City" : "Град",
    "State or province" : "Област",
    "Country" : "Държава",
    "Address" : "Адрес",
    "(new group)" : "(нова група)",
    "Last name" : "Фамилия",
    "First name" : "Име",
    "Additional names" : "Други имена",
    "Prefix" : "Представка",
    "Suffix" : "Наставка",
    "New contact" : "Нов контакт",
    "Not grouped" : "Негрупирани",
    "Sort by" : "Сортиране по",
    "{addressbook} shared by {owner}" : "{addressbook} споделена с {owner}",
    "Contact could not be created." : "Контакта не може да бъде създаден.",
    "Importing…" : "Внасяне...",
    "Nickname" : "Псевдоним",
    "Detailed name" : "Детайлно име",
    "Notes" : "Бележки",
    "Website" : "Уеб страница",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Домашен",
    "Work" : "Работен",
    "Other" : "Друг",
    "Groups" : "Групи",
    "Birthday" : "Рожден ден",
    "Anniversary" : "Годишнина",
    "Date of death" : "Дата на смърт",
    "Email" : "Имейл",
    "Instant messaging" : "Чат",
    "Phone" : "Телефон",
    "Mobile" : "Мобилен телефон",
    "Work mobile" : "Служебен телефон",
    "Fax" : "Факс",
    "Fax home" : "Факс домашен",
    "Fax work" : "Факс служебен",
    "Pager" : "Пейджър",
    "Voice" : "Гласов",
    "Car" : "Кола",
    "Work pager" : "Работен пейджър",
    "Social network" : "Социална мрежа",
    "Spouse" : "Съпруг",
    "Child" : "Дете",
    "Mother" : "Майка",
    "Father" : "Баща",
    "Parent" : "Родител",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Роднина",
    "Friend" : "Приятел",
    "Colleague" : "Колега",
    "Manager" : "Управител",
    "Assistant" : "Асистент",
    "Gender" : "Пол",
    "Female" : "Жена",
    "Male" : "Мъж",
    "Details" : "Детайли",
    "Settings" : "Настройки"
},
"nplurals=2; plural=(n != 1);");
